@@ -241,10 +241,8 @@ class Shell(HasRequiredTraits):
                 line.lower(),
             )
             if mm is not None:
-                host_ip = mm.group(2)
-                logger.debug("    inventory match: '%s' = '%s'" % (hostname.lower, host_ip))
+                host_ip = mm.group(3)
                 tmp = stdlib_ip_factory(host_ip)  # This will raise a ValueError
-                print("MATCH host name with inventory", hostname, line)
                 return host_ip
 
         else:
